#[repr(u8)]pub enum Enet1ClkSel {
ENET1_CLK_SEL_0 = 0,
ENET1_CLK_SEL_1 = 1,
}Variants
ENET1_CLK_SEL_0 = 0
ENET1 TX reference clock driven by ref_enetpll. This clock is also output to pins via the IOMUX. ENET_REF_CLK1 function.
ENET1_CLK_SEL_1 = 1
Gets ENET1 TX reference clock from the ENET1_TX_CLK pin. In this use case, an external OSC provides the clock for both the external PHY and the internal controller.
Implementations
Sourceimpl Enet1ClkSel
impl Enet1ClkSel